@@ -129,7 +129,8 @@ src_present_real_sro_for_brl_and_brlmon (SRObject *obj, gchar *reason)
 	braille_scroll = g_strdup (scroll);
 	
 	sro_get_role (obj, &role, SR_INDEX_CONTAINER);
-	if (role == SR_ROLE_TEXT_SL || role == SR_ROLE_TEXT_ML || role == SR_ROLE_TERMINAL || role == SR_ROLE_COMBO_BOX)
+	if (role == SR_ROLE_TEXT_SL || role == SR_ROLE_TEXT_ML || role == SR_ROLE_TERMINAL 
+	    || role == SR_ROLE_COMBO_BOX || role == SR_ROLE_PASSWORD_TEXT)
 	{
 	    SRLong offset;
 	    SRTextAttribute *attr;
